# Dependencies

This file declares all dependencies NuPIC has on third-party code, including their licenses.

## C++ Dependencies

- dense_hash_map ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/dense_hash_map))
- dense_hash_set ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/dense_hash_set))
- libjpeg ([License](http://libjpeg.cvs.sourceforge.net/viewvc/libjpeg/libjpeg/README?view=markup&pathrev=MAIN))
- nupic.core ([GPLv3](https://github.com/numenta/nupic.core/blob/master/LICENSE.txt))
- png ([License](https://github.com/numenta/nupic/blob/master/external/common/include/libpng12/png.h))
- sparse_hash_map ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/sparse_hash_map))
- sparse_hash_set ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/sparse_hash_set))
- sparsetable ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/sparsetable))
- SWiG ([Legal Talk](http://www.swig.org/legal.html))
- type_traits ([License](https://github.com/numenta/nupic/blob/master/external/common/include/google/type_traits.h))
- zlib ([License](https://github.com/numenta/nupic/blob/master/external/common/include/zlib.h))

## Python Dependencies Through Pip

- asteval ([License](https://github.com/newville/asteval/blob/master/LICENSE))
- coverage ([BSD License](https://bitbucket.org/ned/coveragepy/src/b98fc53a0724298fe9ab6d530174a1d511aac890/coverage/__init__.py?at=default#cl-96))
- DBUtils ([OSI 2.1](http://www.webwareforpython.org/DBUtils/Docs/UsersGuide.html#copyright-and-license))
- mock ([BSD License](http://www.voidspace.org.uk/python/mock/))
- numpy ([License](http://www.numpy.org/license.html))
- ordereddict ([MIT License](https://pypi.python.org/pypi/ordereddict))
- pillow ([License](https://github.com/python-pillow/Pillow/blob/master/LICENSE))
- prettytable ([License](https://code.google.com/p/prettytable/source/browse/trunk/COPYING))
- psutil ([BSD License](https://code.google.com/p/psutil/source/browse/LICENSE))
- pycapnp ([License](https://github.com/jparyani/pycapnp/blob/develop/LICENSE))
- PyMySQL ([License](https://github.com/PyMySQL/PyMySQL/blob/master/LICENSE))
- pyproj ([License](https://github.com/jswhit/pyproj/blob/master/LICENSE))
- pytest ([License](https://bitbucket.org/pytest-dev/pytest/src/45921b2e640011d8f169a7f13fd79218f88c7495/LICENSE?at=default))
- pytest-cov ([MIT License](https://github.com/schlamar/pytest-cov/blob/2.0/pytest-cov/LICENSE.txt))
- pytest-xdist ([MIT License](https://bitbucket.org/pytest-dev/pytest-xdist/src/00cfff4834e718fd3c1ccec40811e734d796f631/LICENSE?at=default))
- python-dateutil ([License](http://bazaar.launchpad.net/~dateutil/dateutil/trunk/view/head:/LICENSE))
- PyYAML ([License](https://bitbucket.org/xi/pyyaml/src/ddf211a41bb231c365fece5599b7e484e6dc33fc/LICENSE?at=default))
- unittest2 ([BSD License](https://pypi.python.org/pypi/unittest2))
- validictory ([License](https://github.com/sunlightlabs/validictory/blob/master/LICENSE.txt))
